import { App, Gdk, Widget } from "astal/gtk3"
import style from "./style.scss"
import Bar from "./Bar"
import Hyprland from "gi://AstalHyprland";
import NotificationPopups from "./notifications/NotificationPopups"

const hyprland = Hyprland.get_default();

function find_main_monitor(): Hyprland.Monitor {
    let monitors = hyprland.get_monitors()
    for (let i = 0; i < monitors.length; i++) {
        for (const monitor of ["eDP", "DP", "HDMI-A"]) {
            if (monitors[i].get_name() == monitor + "-" + i) {
                return monitors[i]
            }
        }
    }
    return monitors[0]
}

function register_windows(monitor: Hyprland.Monitor) {
    let gtkMonitor = App.get_monitors()[0].get_display().get_monitor_at_point(monitor.get_x(), monitor.get_y())
    let scale = (monitor.get_width() >= 3000)? 1.2: 1
    Bar(gtkMonitor, scale)
    NotificationPopups(gtkMonitor)
}

function switch_to_best_monitor() {
    let mainMonitor = find_main_monitor()
    for (var wd of App.get_windows()) {
        wd.destroy();
    }
    register_windows(mainMonitor);
}

hyprland.connect("monitor-added", (_, monitor) => {
    switch_to_best_monitor()
})

hyprland.connect("monitor-removed", () => {
    switch_to_best_monitor()
})

App.start({
    css: style,
    iconTheme: "Papirus",
    main() {
        switch_to_best_monitor()
    },
})
